@@ -1,10 +1,10 @@
 /*
 #   idjcmixer.c: central core of IDJC's mixer.
-#   Copyright (C) 2005-2006 Stephen Fairchild
+#   Copyright (C) 2005-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 */
 
 #define _GNU_SOURCE
@@ -539,10 +539,12 @@ void process_audio(jack_nframes_t nframes)
    {
    int samples_todo;		/* The samples remaining counter in the main loop */
    static float df = 1.0;	/* the ducking factor - generated by the compressor */
+   static int mic_proc_counter; /* reduce cpu usage when mic is off */
    /* the following are used to turn the individual microphone inputs into a stereo mix */
    sample_t lmic, rmic, lstr, rstr, lc_micmix, rc_micmix;
    /* the following are used to apply the output of the compressor code to the audio levels */
-   sample_t compressor_gain, noisegate_gain, dfdb, str_normalizer_gain;
+   static float lmic_gain = 1.0, rmic_gain = 1.0;
+   sample_t compressor_gain = 1.0, noisegate_gain = 1.0, dfdb, str_normalizer_gain;
    /* a counter variable used to trigger the volume smoothing on a regular basis */
    static unsigned vol_smooth_count = 0;
    /* index values for reading from a table of fade gain values */
@@ -703,7 +705,6 @@ void process_audio(jack_nframes_t nframes)
       right_mic_noisegate = new_ng;
       new_noisegate_stats = FALSE;
       }
-      
    if (new_normalizer_stats)
       {
       new_normalizer.level = str_normalizer.level;
@@ -740,25 +741,27 @@ void process_audio(jack_nframes_t nframes)
 	    lmic = *lmp * mic_linv * mic_lgain;
 	    rmic = *rmp * mic_rinv * mic_rgain;
 	    }
-	 /* A high pass filter for mains hum, rumble and to counter the close mic effect you get on directional microphones */
-	 if (mic_filter != 0)
+	    
+	 /* update the microphone compression settings */
+	 if (mic_lc || !(mic_proc_counter & 0x3))
 	    {
-	    lmic = digital_filter(left_mic_filter, lmic);
-	    rmic = digital_filter(right_mic_filter, rmic);
+            if (mic_filter != 0)
+               lmic = digital_filter(left_mic_filter, lmic);
+            compressor_gain = compressor(&left_mic_compressor, lmic, 0);
+            noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));
+            lmic_gain = db2level(compressor_gain + noisegate_gain);
 	    }
-         
-	 /* perform the sidechain actions of the compressor and noisegate */
-	 compressor_gain = compressor(&left_mic_compressor, lmic, 0);
-	 noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));
-	 /* apply the sidechain results to the input signal */
-	 
-         lmic *= db2level(compressor_gain + noisegate_gain);
-	 
-	 /* do the same for the right microphone */	 
-	 compressor_gain = compressor(&right_mic_compressor, rmic, 0);
-	 noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));
-	 
-	 rmic *= db2level(compressor_gain + noisegate_gain);
+         if (mic_rc || !(mic_proc_counter & 0x3))
+            {
+            if (mic_filter != 0)
+               rmic = digital_filter(right_mic_filter, rmic);
+            compressor_gain = compressor(&right_mic_compressor, rmic, 0);
+            noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));
+            rmic_gain = db2level(compressor_gain + noisegate_gain);
+            }
+         mic_proc_counter++;
+         lmic *= lmic_gain;
+         rmic *= rmic_gain;
          
 	 if (vol_smooth_count++ % 100 == 0) /* Can change volume level every so many samples */
             update_smoothed_volumes();
@@ -928,25 +931,27 @@ void process_audio(jack_nframes_t nframes)
                lmic = *lmp * mic_linv * mic_lgain;
                rmic = *rmp * mic_rinv * mic_rgain;
                }
-            /* A high pass filter for mains hum, rumble and to counter the close mic effect you get on directional microphones */
-            if (mic_filter != 0)
+            
+            /* update the microphone compression settings */
+            if (mic_lc || !(mic_proc_counter & 0x3))
                {
-               lmic = digital_filter(left_mic_filter, lmic);
-               rmic = digital_filter(right_mic_filter, rmic);
+               if (mic_filter != 0)
+                  lmic = digital_filter(left_mic_filter, lmic);
+               compressor_gain = compressor(&left_mic_compressor, lmic, 0);
+               noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));
+               lmic_gain = db2level(compressor_gain + noisegate_gain);
                }
-            
-            /* perform the sidechain actions of the compressor and noisegate */
-            compressor_gain = compressor(&left_mic_compressor, lmic, 0);
-	    noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));            
-            /* apply the sidechain results to the input signal */
-            
-            lmic *= db2level(compressor_gain + noisegate_gain);
-            
-            /* do the same for the right microphone */	 
-            compressor_gain = compressor(&right_mic_compressor, rmic, 0);
-	    noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));            
-            
-            rmic *= db2level(compressor_gain + noisegate_gain);
+            if (mic_rc || !(mic_proc_counter & 0x3))
+               {
+               if (mic_filter != 0)
+                  rmic = digital_filter(right_mic_filter, rmic);
+               compressor_gain = compressor(&right_mic_compressor, rmic, 0);
+               noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));
+               rmic_gain = db2level(compressor_gain + noisegate_gain);
+               }
+            mic_proc_counter++;
+            lmic *= lmic_gain;
+            rmic *= rmic_gain;
             
             if (vol_smooth_count++ % 100 == 0) /* Can change volume level every so many samples */
                update_smoothed_volumes();
@@ -1110,25 +1115,27 @@ void process_audio(jack_nframes_t nframes)
                   lmic = *lmp * mic_linv * mic_lgain;
                   rmic = *rmp * mic_rinv * mic_rgain;
                   }
-               /* A high pass filter for mains hum, rumble and to counter the close mic effect you get on directional microphones */
-               if (mic_filter != 0)
+               
+               /* update the microphone compression settings */
+               if (mic_lc || !(mic_proc_counter & 0x3))
                   {
-                  lmic = digital_filter(left_mic_filter, lmic);
-                  rmic = digital_filter(right_mic_filter, rmic);
+                  if (mic_filter != 0)
+                     lmic = digital_filter(left_mic_filter, lmic);
+                  compressor_gain = compressor(&left_mic_compressor, lmic, 0);
+                  noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));
+                  lmic_gain = db2level(compressor_gain + noisegate_gain);
                   }
-               
-               /* perform the sidechain actions of the compressor and noisegate */
-               compressor_gain = compressor(&left_mic_compressor, lmic, 0);
- 	       noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));            
-               /* apply the sidechain results to the input signal */
-               
-               lmic *= db2level(compressor_gain + noisegate_gain);
-               
-               /* do the same for the right microphone */	 
-               compressor_gain = compressor(&right_mic_compressor, rmic, 0);
- 	       noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));            
-               
-               rmic *= db2level(compressor_gain + noisegate_gain);
+               if (mic_rc || !(mic_proc_counter & 0x3))
+                  {
+                  if (mic_filter != 0)
+                     rmic = digital_filter(right_mic_filter, rmic);
+                  compressor_gain = compressor(&right_mic_compressor, rmic, 0);
+                  noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));
+                  rmic_gain = db2level(compressor_gain + noisegate_gain);
+                  }
+               mic_proc_counter++;
+               lmic *= lmic_gain;
+               rmic *= rmic_gain;
                
                if (vol_smooth_count++ % 100 == 0) /* Can change volume level every so many samples */
                   update_smoothed_volumes();
@@ -1290,25 +1297,27 @@ void process_audio(jack_nframes_t nframes)
                      lmic = *lmp * mic_linv * mic_lgain;
                      rmic = *rmp * mic_rinv * mic_rgain;
                      }
-                  /* A high pass filter for mains hum, rumble and to counter the close mic effect you get on directional microphones */
-                  if (mic_filter != 0)
+                  
+                  /* update the microphone compression settings */
+                  if (mic_lc || !(mic_proc_counter & 0x3))
                      {
-                     lmic = digital_filter(left_mic_filter, lmic);
-                     rmic = digital_filter(right_mic_filter, rmic);
+                     if (mic_filter != 0)
+                        lmic = digital_filter(left_mic_filter, lmic);
+                     compressor_gain = compressor(&left_mic_compressor, lmic, 0);
+                     noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));
+                     lmic_gain = db2level(compressor_gain + noisegate_gain);
                      }
-                  
-                  /* perform the sidechain actions of the compressor and noisegate */
-                  compressor_gain = compressor(&left_mic_compressor, lmic, 0);
- 	          noisegate_gain = noisegate(&left_mic_noisegate, digital_filter(ng_left_filter, lmic));            
-                  
-                  /* apply the sidechain results to the input signal */
-                  lmic *= db2level(compressor_gain + noisegate_gain);
-                  
-                  /* do the same for the right microphone */	 
-                  compressor_gain = compressor(&right_mic_compressor, rmic, 0);
- 	          noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));            
-                  
-                  rmic *= db2level(compressor_gain + noisegate_gain);
+                  if (mic_rc || !(mic_proc_counter & 0x3))
+                     {
+                     if (mic_filter != 0)
+                        rmic = digital_filter(right_mic_filter, rmic);
+                     compressor_gain = compressor(&right_mic_compressor, rmic, 0);
+                     noisegate_gain = noisegate(&right_mic_noisegate, digital_filter(ng_right_filter, rmic));
+                     rmic_gain = db2level(compressor_gain + noisegate_gain);
+                     }
+                  mic_proc_counter++;
+                  lmic *= lmic_gain;
+                  rmic *= rmic_gain;
                   
                   if (vol_smooth_count++ % 100 == 0) /* Can change volume level every so many samples */
                      update_smoothed_volumes();
@@ -1583,6 +1592,21 @@ void atexit_handler()
       jack_client_close(client);
    }
 
+void send_metadata_update(struct xlp_dynamic_metadata *dm)
+   {
+   pthread_mutex_lock(&(dm->meta_mutex));
+   if (dm->data_type < DM_JOINED_UC)
+      {
+      fprintf(stdout, "new_metadata=d%d:%sd%d:%sd%d:%sd9:%09dd9:%09dx\n", strlen(dm->artist), dm->artist, strlen(dm->title), dm->title, strlen(dm->artist_title), dm->artist_title, dm->current_audio_context, dm->rbdelay);
+      }
+   else
+      {
+      fprintf(stderr, "send_metadata_update: utf16 chapter info not supported\n");
+      }
+   dm->data_type = DM_NONE_NEW;
+   pthread_mutex_unlock(&(dm->meta_mutex));
+   }
+
 int main(int argc, char **argv)
    {
    FILE *fp=stdin;
@@ -2108,7 +2132,7 @@ int main(int argc, char **argv)
       if (!strcmp(action, "remakestrl"))
          {
 	 jack_port_disconnect(client, stream_left_port);
-	 jack_connect(client, "idjc-mx:str_lt", "idjc-srv:lt_in");	/* this is kludgy */
+	 jack_connect(client, "idjc-mx:str_lt", "idjc-sc:lt_in");	/* this is kludgy */
 	 if (strcmp(strl, "default"))
             {
             if (strl[0] != '\0')
@@ -2124,7 +2148,7 @@ int main(int argc, char **argv)
       if (!strcmp(action, "remakestrr"))
          {
 	 jack_port_disconnect(client, stream_right_port);
-	 jack_connect(client, "idjc-mx:str_rt", "idjc-srv:rt_in");
+	 jack_connect(client, "idjc-mx:str_rt", "idjc-sc:rt_in");
 	 if (strcmp(strr, "default"))
             {
             if (strr[0] != '\0')
@@ -2152,8 +2176,8 @@ int main(int argc, char **argv)
       if (!strcmp(action, "serverbind"))
          {
          fprintf(stderr, "remaking connection to server\n");
-         jack_connect(client, "idjc-mx:str_lt", "idjc-srv:lt_in"); 
-         jack_connect(client, "idjc-mx:str_rt", "idjc-srv:rt_in");
+         jack_connect(client, "idjc-mx:str_lt", "idjc-sc:lt_in"); 
+         jack_connect(client, "idjc-mx:str_rt", "idjc-sc:rt_in");
          }
       if (!strcmp(action, "requestlevels"))
          {
@@ -2196,6 +2220,8 @@ int main(int argc, char **argv)
             		 "interlude_cid=%d\n"
             		 "left_audio_runout=%d\n"
             		 "right_audio_runout=%d\n"
+            		 "left_additional_metadata=%d\n"
+            		 "right_additional_metadata=%d\n"
 			 "end\n",
 			 mic_l_peak_db, mic_r_peak_db, str_l_peak_db, str_r_peak_db,
 			 mic_l_rms_db, mic_r_rms_db, str_l_rms_db, str_r_rms_db,
@@ -2214,9 +2240,15 @@ int main(int argc, char **argv)
                          plr_j->current_audio_context,
                          plr_i->current_audio_context,
             		 left_audio_runout && (!(plr_l->current_audio_context & 0x1)),
-            		 right_audio_runout && (!(plr_r->current_audio_context & 0x1)));
+            		 right_audio_runout && (!(plr_r->current_audio_context & 0x1)),
+            		 plr_l->dynamic_metadata.data_type,
+            		 plr_r->dynamic_metadata.data_type);
 	 /* tell the jack mixer it can reset its vu stats now */
 	 reset_vu_stats_f = TRUE;
+	 if (plr_l->dynamic_metadata.data_type)
+	    send_metadata_update(&(plr_l->dynamic_metadata));
+	 if (plr_r->dynamic_metadata.data_type)
+	    send_metadata_update(&(plr_r->dynamic_metadata));
 	 fflush(stdout);
          }
       }
