@@ -1,10 +1,10 @@
 /*
 #   mp3dec.h: decodes mp3 file format for xlplayer
-#   Copyright (C) 2007 Stephen Fairchild
+#   Copyright (C) 2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,14 +13,15 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "../config.h"
 #ifdef HAVE_MAD
 
 #include "xlplayer.h"
+#include "mp3tagread.h"
 
 struct mp3decode_vars
    {
@@ -34,6 +35,8 @@ struct mp3decode_vars
    int resample;
    int nchannels;
    int samplerate;
+   struct mp3taginfo taginfo;
+   struct chapter *current_chapter;
    };
 
 int mp3decode_reg(struct xlplayer *xlplayer);
