@@ -1,10 +1,10 @@
 /*
 #   vorbisdec.h: ogg vorbis file decoder for xlplayer
-#   Copyright (C) 2007 Stephen Fairchild
+#   Copyright (C) 2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "xlplayer.h"
@@ -24,9 +24,11 @@ struct vorbisdecode_vars
    FILE *fp;
    OggVorbis_File vf;
    vorbis_info *vi;
+   vorbis_comment *vc;
    int resample;
    char *ibuf;
-   float *flbuf; 
+   float *flbuf;
+   int link;
    };
 
 int vorbisdecode_reg(struct xlplayer *xlplayer);
