@@ -1,10 +1,10 @@
 /*
 #   xlplayer.c: player decoder module for idjc
-#   Copyright (C) 2006-2007 Stephen Fairchild
+#   Copyright (C) 2006-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 */
 
 #define _GNU_SOURCE
@@ -207,8 +207,11 @@ void xlplayer_write_channel_data(struct xlplayer *self)
       self->write_deferred = FALSE;
       if (self->sleep_samples > 6000)
          {
+         if (self->sleep_samples > 12000)
+            usleep(20000);
+         else
+            usleep(10000);
          self->sleep_samples = 0;
-         usleep(10000);
          }
       }
    }
@@ -458,7 +461,7 @@ struct xlplayer *xlplayer_create(int samplerate, size_t rbsize, char *playername
       exit(5);
       }
    self->rbsize = rbsize;
-
+   self->rbdelay = (rbsize >> 2) * 1000 / samplerate;
    if (!(self->left_ch = jack_ringbuffer_create(rbsize)))
       {
       fprintf(stderr, "xlplayer: ringbuffer creation failure");
@@ -499,6 +502,11 @@ struct xlplayer *xlplayer_create(int samplerate, size_t rbsize, char *playername
       fprintf(stderr, "xlplayer: playback speed converter initialisation failure");
       exit(5);
       }
+   if (pthread_mutex_init(&(self->dynamic_metadata.meta_mutex), NULL))
+      {
+      fprintf(stderr, "xlplayer: failed initialising metadata_mutex\n");
+      exit(5);
+      }
    self->pbsrb_l = malloc(PBSPEED_INPUT_BUFFER_SIZE);
    self->pbsrb_r = malloc(PBSPEED_INPUT_BUFFER_SIZE);
    self->pbsrb_lf = malloc(PBSPEED_INPUT_BUFFER_SIZE);
@@ -534,13 +542,14 @@ struct xlplayer *xlplayer_create(int samplerate, size_t rbsize, char *playername
       usleep(10000);
    return self;
    }
- 
+
 void xlplayer_destroy(struct xlplayer *self)
    {
    if (self)
       {
       self->command = CMD_CLEANUP;
       pthread_join(self->thread, NULL);
+      pthread_mutex_destroy(&(self->dynamic_metadata.meta_mutex));
       free(self->pbsrb_l);
       free(self->pbsrb_r);
       free(self->pbsrb_lf);
@@ -556,7 +565,7 @@ void xlplayer_destroy(struct xlplayer *self)
       free(self);
       }
    }
-   
+
 int xlplayer_play(struct xlplayer *self, char *pathname, int seek_s, int size)
    {
    if (self->playmode == PM_PLAYING)
@@ -571,12 +580,12 @@ int xlplayer_play(struct xlplayer *self, char *pathname, int seek_s, int size)
       usleep(10000);
    return self->initial_audio_context;
    }
-   
+
 int xlplayer_playmany(struct xlplayer *self, char *playlist, int loop_f)
    {
    char *start = playlist, *end;
    int payloadlen, i;
-   
+
    if (self->playmode == PM_PLAYING)
       xlplayer_eject(self);
    /* this is where we parse the playlist starting with getting the number of entries */
@@ -616,8 +625,8 @@ int xlplayer_playmany(struct xlplayer *self, char *playlist, int loop_f)
    while (self->command)
       usleep(10000);
    return self->initial_audio_context;
-   }   
-   
+   }
+
 int xlplayer_play_noflush(struct xlplayer *self, char *pathname, int seek_s, int size)
    {
    self->noflush = TRUE;
@@ -846,3 +855,23 @@ void xlplayer_destroy_fadein_lookup()
    if (fadeinlookuptable)
       free(fadeinlookuptable);
    }
+
+void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *artist_title, int usedelay)
+   {
+   struct xlp_dynamic_metadata *dm = &(xlplayer->dynamic_metadata);
+   
+   pthread_mutex_lock(&(dm->meta_mutex));
+   dm->data_type = type;
+   if (dm->artist)
+      free(dm->artist);
+   if (dm->title)
+      free(dm->title);
+   if (dm->artist_title)
+      free(dm->artist_title);
+   dm->artist = strdup(artist);
+   dm->title = strdup(title);
+   dm->artist_title = strdup(artist_title);
+   dm->current_audio_context = xlplayer->current_audio_context;
+   dm->rbdelay = xlplayer->rbdelay * usedelay;
+   pthread_mutex_unlock(&(dm->meta_mutex));
+   }
