@@ -1,10 +1,10 @@
 /*
 #   xlplayer.h: player decoder module for idjc
-#   Copyright (C) 2006-2007 Stephen Fairchild
+#   Copyright (C) 2006-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef XLPLAYER_H
@@ -46,6 +46,19 @@ enum command_t {CMD_COMPLETE, CMD_PLAY, CMD_EJECT, CMD_CLEANUP, CMD_THREADEXIT,
 
 enum playmode_t {PM_STOPPED, PM_INITIATE, PM_PLAYING, PM_EJECTING };
 
+enum metadata_t {DM_NONE_NEW, DM_SPLIT_U8, DM_JOINED_U8, DM_SPLIT_L1, DM_JOINED_L1, DM_JOINED_UC, DM_JOINED_UCBE};
+
+struct xlp_dynamic_metadata	/* song titles can change mid-file */
+   {				/* this structure facilitates transmission */
+   pthread_mutex_t meta_mutex;	/* back to the user interface */
+   char *artist;
+   char *title;
+   char *artist_title;
+   int current_audio_context;
+   int rbdelay;
+   enum metadata_t data_type;
+   };
+
 struct xlplayer
    {
    jack_ringbuffer_t *left_ch;		/* main playback buffer */
@@ -53,6 +66,7 @@ struct xlplayer
    jack_ringbuffer_t *left_fade;	/* buffers used for fade - swapped with above when needed */
    jack_ringbuffer_t *right_fade;
    size_t rbsize;			/* the size of the jack ringbuffers in bytes */
+   int rbdelay;				/* rough time lag of the ringbuffers in ms */
    size_t op_buffersize;		/* the current size of the player output buffers */
    char *pathname;			/* the pathname of the music file being played */
    char **playlist;			/* the playlist as an array of pointers */
@@ -110,6 +124,7 @@ struct xlplayer
    void (*dec_init)(struct xlplayer *);	/* audio decoder init function */
    void (*dec_play)(struct xlplayer *);	/* function that decodes one frame of audio data */
    void (*dec_eject)(struct xlplayer *);/* function that cleans up after the decoder */
+   struct xlp_dynamic_metadata dynamic_metadata;
    };
 
 /* xlplayer_create: create an instance of the player */
@@ -172,4 +187,7 @@ void xlplayer_demux_channel_data(struct xlplayer *self, jack_default_audio_sampl
 /* cause the cached pcm data to be written out to the jack ringbuffer */
 void xlplayer_write_channel_data(struct xlplayer *self);
 
+/* provide data for sending back to the user interface */
+void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *artist_title, int usedelay);
+
 #endif /* XLPLAYER_H */
