@@ -1,9 +1,9 @@
 #   IDJCmixprefs.py: Preferences window code for IDJC
-#   Copyright (C) 2005 Stephen Fairchild
+#   Copyright (C) 2005-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -12,8 +12,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 
 import pygtk
 pygtk.require('2.0')
@@ -472,11 +472,12 @@ class mixprefs:
       self.send_new_microphone_stats() 
       
    def cb_autopause(self, widget, data):
-      if data == "on_delay changed":
-         self.parent.server_window.serv_cmd.write("APOD=%f\nACTN=Pause\nend\n" % widget.get_value())
-      if data == "off_thresh changed":
-         self.parent.server_window.serv_cmd.write("APTH=%d\nACTN=Pause\nend\n" % int(widget.get_value()))
-      self.parent.server_window.serv_cmd.flush()
+      pass
+      #if data == "on_delay changed":
+      #   self.parent.server_window.serv_cmd.write("APOD=%f\nACTN=Pause\nend\n" % widget.get_value())
+      #if data == "off_thresh changed":
+      #   self.parent.server_window.serv_cmd.write("APTH=%d\nACTN=Pause\nend\n" % int(widget.get_value()))
+      #self.parent.server_window.serv_cmd.flush()
 	 
    def meter_callback(self, widget, data):
       if data[0] == "meter":
@@ -628,7 +629,7 @@ class mixprefs:
       mic_vu_hbox.show()
       mp3_utf8_hbox = gtk.HBox()
       leftvbox.add(mp3_utf8_hbox)
-      mp3_utf8_hbox.show()
+      #mp3_utf8_hbox.show()
       speed_variance_box = gtk.HBox()
       leftvbox.add(speed_variance_box)
       speed_variance_box.show()
@@ -720,6 +721,7 @@ class mixprefs:
       keeppass_box.pack_start(self.keeppass, False, False, 0)
       self.keeppass.show()
       self.mp3_utf8 = gtk.CheckButton(mp3_utf8_text)
+      self.mp3_utf8.set_active(True)
       mp3_utf8_hbox.pack_start(self.mp3_utf8, False, False, 5)
       self.mp3_utf8.show()
 
@@ -898,8 +900,8 @@ class mixprefs:
       startupbox.pack_start(self.ap_startup_pref, False, False, 0)
       self.ap_startup_pref.show()
       
-      outervbox.pack_start(frame, False, False, 0)
-      frame.show()
+      #outervbox.pack_start(frame, False, False, 0)
+      #frame.show()
       
       # Player settings at application start selection
       
@@ -1931,7 +1933,6 @@ class mixprefs:
          "normalize"	 : self.normalize,
          "dither"	 : self.dither,
          "recallsession" : self.restore_session_option,
-         "MP3usesUTF8"   : self.mp3_utf8,
          "keeppass"      : self.keeppass,
          "ee_appstart"	 : self.appstart_event,
          "ee_appexit"    : self.appexit_event,
