@@ -1,9 +1,9 @@
 #   idjc-announce.py: X-Chat plug-in for IDJC
-#   Copyright (C) 2005-2006 Stephen Fairchild
+#   Copyright (C) 2005-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -12,11 +12,11 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 
 __module_name__ = "idjc-announce"
-__module_version__ = "1.1"
+__module_version__ = "1.2"
 __module_description__ = "Announce tracks playing in idjc"
 
 import xchat
@@ -36,20 +36,20 @@ def listening(word, word_eol, userdata):	# Announce in the current channel
    else:
       xchat.command("me is listening to: " + song)
    return xchat.EAT_XCHAT			# Processing of the command stops here
-   
-def shell(word, word_eol, userdata):
-   if len(word_eol) > 1:
-      data = os.popen(word_eol[1]).read()[:-1]
-      if userdata == "spam":
-         xchat.command("say \x0312Executing shell command:\x03 " + word_eol[1])
-         data = data.splitlines()
-         for line in data:
-            xchat.command("say " + line)
+
+def execute_command(word, word_eol, userdata):
+   if len(word_eol) > userdata:
+      send, recv = os.popen2(word)
+      send.close()
+      output = recv.read()[:-1].splitlines()
+      recv.close()
+      if not output:
+         print "No output. Is", word[0], "installed?"
       else:
-         print "Executing shell command:", word_eol[1]
-         print data
+         for line in output:
+            xchat.command("say " + line)
    else:
-      print "Enter a shell command you want to execute."
+      print "Not enough parameters"
    return xchat.EAT_XCHAT
 
 def stop_cb(word, word_eol, userdata):
@@ -133,7 +133,6 @@ idjc = os.environ.get("HOME") + "/.idjc/"	# The file path of the ~/.idjc directo
 xchat.hook_command("announce", start_cb)	# Adds X-Chat command /announce
 xchat.hook_command("stopannounce", stop_cb)	# Adds X-Chat command /stopannounce
 xchat.hook_command("listening", listening)	# Shows what the idjc listener is listening to
-xchat.hook_command("shell", shell)		# Execute a command in a shell
-xchat.hook_command("ashell", shell, "spam")	# As above but display it to the channel
+xchat.hook_command("cowsay", execute_command, 1)# This is really silly
 start_cb(None, None, None)			# Automatically start the annoucements
-print "Commands are: /announce /stopannounce /listening /shell /ashell"
+print "Commands are: /announce /stopannounce /listening /cowsay"
