@@ -1,9 +1,9 @@
 #   idjcgui.py: Main python code of IDJC
-#   Copyright (C) 2005 Stephen Fairchild
+#   Copyright (C) 2005-2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -12,13 +12,13 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 
 appname= "Internet DJ Console"
 copyright = "Copyright 2005-2007 Stephen Fairchild"
 copyright2 = u"\xA9 2005-2007 Stephen Fairchild"	# As above but uses copyright character (c)
-license = "Released under the GNU General Public License V2.0"
+license = "Released under the GNU General Public License V3.0"
 # version is set in the configure.in file
 
 import locale, os, sys, fcntl
@@ -71,11 +71,16 @@ import pygtk
 pygtk.require('2.0')
 import gtk, gobject, time, fcntl, signal, stat
 
+try:
+   pango.Font	# some users will not need to import pango explicitly
+except:
+   import pango
+
 # import the python modules for my app
 try:
    from idjc_config import *
    from IDJCmedia import *
-   from IDJCservergui import *
+   from sourceclientgui import *
    from IDJCmixprefs import *
    from IDJCjingles import *
    from langheader import *
@@ -83,7 +88,7 @@ except:
    sys.path.append(os.environ.get("pkgpyexecdir"))
    from idjc_config import *
    from IDJCmedia import *
-   from IDJCservergui import *
+   from sourceclientgui import *
    from IDJCmixprefs import *
    from IDJCjingles import *
    from langheader import *
@@ -494,6 +499,9 @@ class idjc_shutdown_dialog:
   
 class MainWindow:
    def send_new_mixer_stats(self):
+      def xtp(in_str):			# xchat text package maker
+         return "".join(("d", str(len(in_str)), ":", in_str))
+      
       string_to_send = ":%03d:%03d:%03d:%03d:%03d:%d:%d%d%d%d%d:%d%d:%d%d%d:%d%d%d%d:%d:%d:%d:%d:%d:%f:%f:%d:" % (
 						self.deckadj.get_value(),
 						self.crossadj.get_value(),
@@ -579,21 +587,22 @@ class MainWindow:
 	       
             # Write out the x-chat track announcement to a file
             # note how the announcement is done on a time delay
+            
             if self.prefs_window.announce_enable.get_active() and self.server_window.connect_button.get_active():
-	       message_text = "d" + str(len(self.prefs_window.nickentry.get_text().encode("utf-8"))) + ":" +			self.prefs_window.nickentry.get_text().encode("utf-8") + "d" +	str(len(self.prefs_window.channelsentry.get_text().encode("utf-8"))) + ":" + 			self.prefs_window.channelsentry.get_text().encode("utf-8")
-               cookedmessage = self.cook(self.prefs_window.announcemessageentry.get_text())
-	       message_text = message_text + "d" + str(len(cookedmessage)) + ":" + cookedmessage
-	       timestr = str(int(time.time() + self.prefs_window.announcedelayadj.get_value()))
-	       message_text = message_text +  "d" + str(len(timestr)) + ":" + timestr
-	       gobject.timeout_add(int(self.prefs_window.announcedelayadj.get_value() * 1000 - 500), self.announce_the_track, message_text)
-            self.server_window.new_meta(self.metadata, self.artist, self.title)    
+	       message_text = "".join((
+               		xtp(self.prefs_window.nickentry.get_text().encode("utf-8")),
+                   	xtp(self.prefs_window.channelsentry.get_text().encode("utf-8")),
+                        xtp(self.metadata.encode("utf-8")),
+                        xtp(str(int(time.time() + self.prefs_window.announcedelayadj.get_value())))))
+	       gobject.timeout_add(int(self.prefs_window.announcedelayadj.get_value() * 1000 - 500), self.xchat_announce_the_track, message_text)
+            self.server_window.new_metadata(self.artist, self.title, self.metadata)
          else:
             if self.profile == "default":
 	       self.window.set_title(self.appname)
             else:
                self.window.set_title(self.appname + "  (" + self.profile + ")")
 
-   def announce_the_track(self, message):
+   def xchat_announce_the_track(self, message):
       try:
 	 file = open(self.idjcroot + "announce.xchat", "w")
 	 fcntl.flock(file.fileno(), fcntl.LOCK_EX)
@@ -603,14 +612,63 @@ class MainWindow:
       except IOError:
 	 print "Problem writing the announcement file to disk"
       return False  
+
+   def songname_decode(self, data):
+      data = data[13:]
+      i = 1
+      while 1:
+         if data[i - 1] != "d":
+            print "songname_decode: WARNING, read past end boundary"
+            yield None
+            continue
+         colon_index = data.index(":", i)
+         text_length = int(data[i : colon_index])
+         text = data[colon_index + 1 : colon_index + 1 + text_length]
+         yield text
+         i = colon_index + text_length + 2
+
+   def update_songname(self, player, data, infotype):
+      gen = self.songname_decode(data)
+      artist = gen.next()
+      title = gen.next()
+      artist_title = gen.next()
+      player_context = int(gen.next())
+      time_lag = int(gen.next())
       
-   def cook(self, rawtext):
-      rawtext = rawtext.replace("%s", self.metadata)
-      rawtext = rawtext.replace("%n", self.server_window.name_entry.get_text())
-      rawtext = rawtext.replace("%u", self.server_window.url_entry.get_text())
-      rawtext = rawtext.replace("%d", self.server_window.description_entry.get_text())
-      return rawtext.encode("utf-8")
-	 
+      if infotype == 1:
+         song = artist.decode("utf-8", "replace") + u" - " + title.decode("utf-8", "replace")
+      if infotype == 2:
+         song = artist_title.decode("utf-8", "replace")
+         artist = ""
+         title = artist_title
+      if infotype == 3:
+         song = artist.decode("iso8859-1", "replace") + u" - " + title.decode("iso8859-1", "replace")
+         artist = artist.decode("iso8859-1", "replace").encode("utf-8", "replace")
+         title = title.decode("iso8859-1", "replace").encode("utf-8", "replace")
+      if infotype == 4:
+         song = artist_title.decode("iso8859-1", "replace")
+         artist = ""
+         title = song.encode("utf-8", "replace")
+      if infotype > 4:	# unicode chapter tags unsupported
+         return
+      if not player_context & 1:
+         time_lag = 0
+      else:
+         time_lag = int(time_lag / player.pbspeedfactor)
+      gobject.timeout_add(time_lag, self.new_songname_timeout, (song, artist, title, player, player_context))
+
+   def new_songname_timeout(self, (song, artist, title, player, player_context)):
+      gtk.gdk.threads_enter()
+      if player.player_cid == (player_context | 1):
+         player.songname = song
+         player.artist = artist
+         player.title = title
+         self.send_new_mixer_stats()
+      else:
+         print "context mismatch, player context id =", player.player_cid, "metadata update carries context id =", player_context
+      gtk.gdk.threads_leave()
+      return False
+
    def callback(self, widget, data):
       print "%s was pressed" % data
       if data == "Show about":
@@ -658,7 +716,7 @@ class MainWindow:
             self.player_right.advance()
       if data == "Server":
          self.server_window.window.present()
-         self.server_window.password_entry.grab_focus()
+         #self.server_window.password_entry.grab_focus()
       if data == "Prefs":
          self.prefs_window.window.present()
       if data == "Jingles":
@@ -908,36 +966,21 @@ class MainWindow:
       if self.session_loaded:
          self.save_session()
          self.prefs_window.save_player_prefs()
+         self.server_window.save_session_settings()
       try:
          gtk.main_quit()
          os.unlink(self.idjcroot + "command")
       except:
          pass
       gtk.gdk.threads_leave()
+      time.sleep(0.3)
       sys.exit(0)
 
    def destroy(self, widget=None, data=None):
       signal.signal(signal.SIGINT, self.destroy_hard)
       if self.crosspass:
          gobject.source_remove(self.crosspass)
-      if self.server_window.server_on_f == True:
-         print "Shutdown: awaiting disconnection from server"
-         self.server_window.disconnect()
-         while self.server_window.server_on_f:
-            gtk.gdk.threads_leave()
-            self.server_window.server_monitor()
-            gtk.gdk.threads_enter()
-            time.sleep(0.1)
-      if self.server_window.is_recording == True:
-         print "Shutdown: stopping recording"
-         self.server_window.stop_recording()
-         while self.server_window.is_saving:
-            gtk.gdk.threads_leave()
-            self.server_window.server_monitor()
-            gtk.gdk.threads_enter()
-            time.sleep(0.1)
-      gobject.source_remove(self.server_window.servmon_source_id)
-
+      self.server_window.cleanup()
       self.mic_select.set_active(False)
       self.aux_select.set_active(False)
       self.player_left.cleanup()
@@ -948,16 +991,17 @@ class MainWindow:
       self.send_new_mixer_stats()
       gobject.source_remove(self.statstimeout)
       gobject.source_remove(self.vutimeout)
+      self.server_window.source_client_close()
+      self.mixer_ctrl.close()
       self.save_session()
       self.prefs_window.save_player_prefs()
-      self.server_window.serv_cmd.close()
-      self.mixer_ctrl.close()
-      self.server_window.save(self.idjc)
+      self.server_window.save_session_settings()
       self.prefs_window.appexit_event.activate()	# run user specified command for application exit
       if os.path.isfile(self.idjcroot + "command"):
          os.unlink(self.idjcroot + "command")
-      gtk.main_quit()
-      time.sleep(0.35)	# Allow time for all subthreads/programs time to exit 
+      if gtk.main_level():
+         gtk.main_quit()
+      time.sleep(0.3)	# Allow time for all subthreads/programs time to exit 
       try:
          os.unlink(self.idjcroot + "command")			# intentionally did this twice
       except:
@@ -966,7 +1010,7 @@ class MainWindow:
       sys.exit(0)
 
    def delete_event(self, widget, event, data=None):
-      if self.server_window.server_on_f == True:
+      if self.server_window.is_streaming:
          idjc_shutdown_dialog(self.window_group, self.destroy, None, (is_streaming_text, question_quit_text))
          return True
       elif self.server_window.is_recording:
@@ -1026,7 +1070,7 @@ class MainWindow:
          self.prefs_window.send_new_microphone_stats()
          self.prefs_window.send_new_normalizer_stats()
          self.prefs_window.bind_jack_ports()
-         self.mixer_write("ACTN=serverbind\n", True)	# tell mixer to bind audio with the server module
+         self.mixer_write("ACTN=serverbind\n", True)	# tell mixer to bind audio with the sourceclient module
          self.player_left.next.clicked()
          self.player_right.next.clicked()
          self.jingles.stop.clicked()
@@ -1203,7 +1247,20 @@ class MainWindow:
 	    print "key value", key, "missing from vumap"
       if self.jingles.playing == True and int(self.jingles_playing) == 0:
          self.jingles.stop_player(False)
-
+      
+      if self.metadata_left_ctrl.get_value():	# handle dynamic metadata
+         while 1:
+            line = self.mixer_read()
+            if line.startswith("new_metadata="):
+               self.update_songname(self.player_left, line, self.metadata_left_ctrl.get_value())
+               break
+      if self.metadata_right_ctrl.get_value():
+         while 1:
+            line = self.mixer_read()
+            if line.startswith("new_metadata="):
+               self.update_songname(self.player_right, line, self.metadata_right_ctrl.get_value())
+               break
+      
       if locking:
          gtk.gdk.threads_leave()
       return True
@@ -1335,12 +1392,10 @@ class MainWindow:
             print "For more help visit http://idjc.sourceforge.net"
          raise self.initcleanexit
  
-      if shoutenabled == 0:
-         print "Streaming is disabled.  To enable it install libshout then reinstall IDJC."
       self.denc = display_enc
       self.fenc = file_enc
       print "display encoding:", self.denc, "filesystem encoding:", self.fenc
-      
+ 
       ask_profile = not os.path.isfile(self.idjcroot + "do-not-ask-profile")
       if self.profile == "":
          if ask_profile == False:
@@ -2022,14 +2077,12 @@ class MainWindow:
       close_menu_item.show()
       close_menu_item.connect("activate", self.close_window, self.close_menu)
 
-      # Instantiate the other windows
+      # Create the jingles player
+      self.jingles = jingles(self)
+
+      # Variable initialisation
       self.songname = u""
       self.newmetadata = False
-      self.server_window = server_window(self)
-      self.server_window.load(self.idjc)
-      self.jingles = jingles(self)
-            
-      # Variable initialisation
       self.showing_left_file_requester = False
       self.showing_right_file_requester = False
       self.metadata = ""
@@ -2054,6 +2107,8 @@ class MainWindow:
       self.jingles.mixer_interlude_cid = int_object(0)
       self.player_left.runout = int_object(0)
       self.player_right.runout = int_object(0)
+      self.metadata_left_ctrl = int_object(0)
+      self.metadata_right_ctrl = int_object(0)
       self.fullwinx = int_object(1)
       self.fullwiny = int_object(1)
       self.minwinx = int_object(1)
@@ -2084,22 +2139,24 @@ class MainWindow:
 	 "str_r_peak"	: self.str_r_peak,
 	 "str_l_rms"	: self.str_l_rms_vu,
 	 "str_r_rms"	: self.str_r_rms_vu,
-	 "left_compressor_gain"  : self.left_compressor_gain,
-	 "right_compressor_gain" : self.right_compressor_gain,
-         "jingles_playing"	 : self.jingles_playing,
-         "left_elapsed"		 : self.player_left.playtime_elapsed,
-         "right_elapsed"	 : self.player_right.playtime_elapsed,
-         "left_playing"		 : self.player_left.mixer_playing,
-         "right_playing"	 : self.player_right.mixer_playing,
-         "interlude_playing"	 : self.interlude_playing,
-         "left_signal"		 : self.player_left.mixer_signal_f,
-         "right_signal"		 : self.player_right.mixer_signal_f,
-         "left_cid"		 : self.player_left.mixer_cid,
-         "right_cid"		 : self.player_right.mixer_cid,
-         "jingles_cid"		 : self.jingles.mixer_jingles_cid,
-         "interlude_cid"	 : self.jingles.mixer_interlude_cid,
-         "left_audio_runout"	 : self.player_left.runout,
-         "right_audio_runout"	 : self.player_right.runout
+	 "left_compressor_gain"     : self.left_compressor_gain,
+	 "right_compressor_gain"    : self.right_compressor_gain,
+         "jingles_playing"	    : self.jingles_playing,
+         "left_elapsed"		    : self.player_left.playtime_elapsed,
+         "right_elapsed"	    : self.player_right.playtime_elapsed,
+         "left_playing"		    : self.player_left.mixer_playing,
+         "right_playing"	    : self.player_right.mixer_playing,
+         "interlude_playing"	    : self.interlude_playing,
+         "left_signal"		    : self.player_left.mixer_signal_f,
+         "right_signal"		    : self.player_right.mixer_signal_f,
+         "left_cid"		    : self.player_left.mixer_cid,
+         "right_cid"		    : self.player_right.mixer_cid,
+         "jingles_cid"		    : self.jingles.mixer_jingles_cid,
+         "interlude_cid"	    : self.jingles.mixer_interlude_cid,
+         "left_audio_runout"	    : self.player_left.runout,
+         "right_audio_runout"	    : self.player_right.runout,
+         "left_additional_metadata" : self.metadata_left_ctrl,
+         "right_additional_metadata": self.metadata_right_ctrl
 	 }
 
       self.prefs_window = mixprefs(self)
@@ -2108,7 +2165,8 @@ class MainWindow:
       self.prefs_window.ask_profile.set_active(ask_profile)
       self.vutimeout = gobject.timeout_add(50, self.vu_update)
       self.statstimeout = gobject.timeout_add(500, self.stats_update)
-
+      self.server_window = sourceclientgui(self)
+      
       signal.signal(signal.SIGINT, self.destroy)
       if not self.simplemixer:
          self.window.resize(self.fullwinx, self.fullwiny)
