@@ -1,11 +1,11 @@
 # -*- encoding: utf-8 -*-
 
 #   langheader.py: GUI internationalisation code of IDJC
-#   Copyright (C) 2005 Stephen Fairchild
+#   Copyright (C) 2007 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
-#   This program is free software; you can redistribute it and/or modify
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -14,8 +14,8 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#   along with this program in the file entitled COPYING.
+#   If not, see <http://www.gnu.org/licenses/>.
 
 import os
 
@@ -40,7 +40,7 @@ loop_all_text = ("Loop All", "Endlos", "Loop All")[li]
 random_text = ("Random", "Zufällig", "Random")[li]
 manual_text = ("Manual", "Manuell", "Manual")[li]
 cue_up_text = ("Cue Up", "Aufreihen", "Cue Up")[li]
-stream_text = (" Stream ", "Stream", " Stream ")[li]
+stream_text = (" Stream ", " Stream ", " Stream ")[li]
 listen_text = (" Listen ", "Hören", " Listen ")[li]
 tracks_played_text = ("Tracks Played", "Gespielte Lieder", "Tracks Played")[li]
 track_history_clear_text = ("Remove Contents", "Inhalt entfernen", "Remove Contents ")[li]
@@ -58,29 +58,34 @@ window_close_text = ("Close", "Close", "Close")[li]
 sequence_text = ("Sequence:", "Sequenz:", "Sequence:")[li]
 
 # Server window stuff
-connection_text = ("Connection", "Verbindung", "Connection")[li]
-encoding_text = ("Encoding", "Format", "Encoding")[li]
-stream_info_text = ("Stream Info", "Stream Info", "Stream Info")[li]
-record_text = ("Record", "Aufnahme", "Record")[li]
+connection_text = (" Connection ", " Verbindung ", " Connection ")[li]
+encoding_text = (" Encoding ", " Format ", " Encoding ")[li]
+stream_info_text = (" Stream Info ", " Stream Info ", " Stream Info ")[li]
+record_text = (" Record ", " Aufnahme ", " Record ")[li]
 server_type_text = ("Type:", "Typ:", "Type:")[li]
-server_hostname_text = ("Host:", "Host:", "Host:")[li]
+server_host_text = ("Host:", "Host:", "Host:")[li]
 server_port_text = ("Port:", "Port:", "Port:")[li]
 server_mount_text = ("Mount:", "Mount:", "Mount:")[li]
 server_login_text = ("Login:", "Login:", "Login:")[li]
-server_password_text = ("Pass:", "Pass:", "Pass:")[li]
+server_passwd_text = ("Pass:", "Pass:", "Pass:")[li]
 dj_name_text = ("DJ Name:", "DJ-Name:", "DJ Name:")[li]
 listen_url_text = ("Listen URL:", "Radio-URL:", "Listen URL:")[li]
 description_text = ("Description:", "Beschreibung:", "Description:")[li]
 genre_text = ("Genre:", "Musikrichtung:", "Genre:")[li]
-metadata_text = ("Metadata:", "Metadaten:", "Metadata:")[li]
+metadata_text = ("Metadata: ", "Metadaten: ", "Metadata: ")[li]
 update_text = ("Update", "Update", "Update")[li]
 send_metadata_text = ("Send Metadata", "Sende Metadaten", "Send Metadata")[li]
 make_public_text = ("Make Public", "Öffentlich", "Make Public")[li]
 server_connect_text = ("Server Connect", "Verbindung herstellen", "Server Connect")[li]
-until_text = ("Until (24hr Time):", "Bis (24hr-Angabe):", "Until (24hr Time)")[li]
+start_streaming_time_text = ("Start:", "Start:", "Start:")[li]
+stop_streaming_time_text = ("Stop:", "Stop:", "Stop:")[li]
 record_filename_text = ("Filename:", "Dateiname:", "Filename:")[li]
 record_artist_text = ("Artist:", "Artist:", "Artist:")[li]
 record_title_text = ("Title:", "Titel:", "Title:")[li]
+test_monitor_text = (" Test / Monitor ", " Test / Monitor ", " Test / Monitor ")[li]
+upon_connection_text = ("Upon connection:", "Upon connection:", "Upon connection:")[li]
+start_recorder_text = ("Start recorder", "Start recorder", "Start recorder")[li]
+start_player_text = ("Start player", "Start player", "Start player")[li]
 
 # Prefs window stuff
 general_tab_text = ("General", "Grundeinstellungen", "General")[li]
@@ -188,9 +193,9 @@ mic_aux_mutex_text = ("Make Mic and Aux buttons mutually exclusive", "Make Mic a
 
 # About tab
 
-licence_text = ("Released under the GNU General Public License V2.0",
-		"Veröffentlicht unter der GNU General Public License V2.0",
-		"Released under the GNU General Public License V2.0")[li]
+licence_text = ("Released under the GNU General Public License V3.0",
+		"Veröffentlicht unter der GNU General Public License V3.0",
+		"Released under the GNU General Public License V3.0")[li]
 
 tagger_window_title_text = ("IDJC Tagger", "IDJC Tagger", "IDJC Tagger")[li]
 tagger_filename_text = ("Filename:", "Dateiname:", "Filename:")[li]
@@ -242,11 +247,11 @@ question_quit_text = ("Do you really want to quit?", "Wirklich beenden?", "Do yo
 
 disconnected_text = ("IDJC Disconnected", "IDJC nicht verbunden", "IDJC Disconnected")[li]
 
-unexpected_text = (("The connection to the radio server failed."), ("Die Verbindung zum Server ist fehlgeschlagen."), ("The connection to the radio server failed."))[li]
+unexpected_text = (("A connection to a radio server failed."), ("Die Verbindung zum Server ist fehlgeschlagen."), ("A connection to a radio server failed."))[li]
 
 timed_out_text = (("Automatically disconnected from the server,", "after the connection timed out."), ("Automatisch vom Server getrennt,", "weil dieser nicht antwortete (timeout)."), ("Automatically disconnected from the server,", "after the connection timed out."))[li]
 
-autoshutdown_text = (("Automatically disconnected from the server.", "Disconnection caused by the shutdown timer."), ("Automatisch vom Server getrennt.", "Grund: shutdown timer."), ("Automatically disconnected from the server.", "Disconnection caused by the shutdown timer."))[li]
+autoshutdown_text = (("An automatic server disconnection occurred.", "Disconnection was caused by a timer."), ("Automatisch vom Server getrennt.", "Grund: shutdown timer."), ("An automatic server disconnection occurred.", "Disconnection was caused by a timer."))[li]
 
 disconnection_text = ("IDJC Disconnection", "IDJC trennt die Verbindung", "IDJC Disonnection")[li]
 
@@ -307,7 +312,7 @@ auxinput_control_menu_text = ("Switch to Aux", "Switch to Aux", "Switch to Aux")
 
 # Stream encoding method
 
-format_text = ("Format", "Format", "Format")[li]
+format_text = (" Format ", " Format ", " Format ")[li]
 
 bitrate_text = ("Bitrate", "Bitrate", "Bitrate")[li]
 
@@ -315,6 +320,12 @@ stereo_text = ("Stereo", "Stereo", "Stereo")[li]
 
 high_quality_abbrev_text = ("HQ", "HQ", "HQ")[li]
 
+ogg_bitrate_nominal_text = ("Nominal Bitrate", "Nominal Bitrate", "Nominal Bitrate")[li]
+
+ogg_bitrate_neg_rel_text = ("Min (-rel)", "Min (-rel)", "Min (-rel)")[li]
+
+ogg_bitrate_pos_rel_text = ("Max (+rel)", "Max (+rel)", "Max (+rel)")[li]
+
 # Fixes for folks that like SuSE for some strange reason.
 
 big_box_toggle_text = ("Counter fix", "Counter fix", "Counter fix")[li]
@@ -366,13 +377,21 @@ popupwindowplaying_text = ("Playing track %d of %d", "Playing track %d of %d", "
 popupwindowtracktotal_text = ("Total number of tracks %d", "Total number of tracks %d", "Total number of tracks %d")[li]
 popupwindowplayduration_text = ("Total play duration %s", "Total play duration %s", "Total play duration %s")[li]
 
-# Playlist resample box
+# resample stuff
 
 player_resample_mode_text = ("Player resample quality", "Player resample quality", "Player resample quality")[li]
 best_quality_resample_text = ("Highest", "Highest", "Highest")[li]
 good_quality_resample_text = ("Good", "Good", "Good")[li]
 fast_resample_text = ("Fast", "Fast", "Fast")[li]
 fastest_resample_text = ("Fastest", "Fastest", "Fastest")[li]
+stream_resample_text = ("Sample rate", "Sample rate", "Sample rate")[li]
+no_resample_text = ("Use JACK sample rate", "Use JACK sample rate", "Use JACK sample rate")[li]
 
+# new server window labels
 
+resample_quality_text = ("Quality", "Quality", "Quality")[li]
+encoding_quality_text = ("Quality (0=best)", "Quality (0=best)", "Quality (0=best)")[li]
+elapsed_recording_text = ("Elapsed:", "Elapsed:", "Elapsed:")[li]
+stream_file_chooser_title_text = ("Select A File To Stream", "Select A File To Stream", "Select A File To Stream")[li]
+save_folder_dialog_title_text = ("Select A Folder To Save To", "Select A Folder To Save To", "Select A Folder To Save To")[li]
 del li
